import QtQuick 2.0
import Sailfish.Silica 1.0
import QtQuick.LocalStorage 2.0
import MetacraneClient 1.0

Page {
    property string crane_name: "Unknown"
    id: page

    Label {
        anchors.top: page.top
        anchors.right: page.right
        text: MetacraneClient.uploadProgress < 0 ? "" :
            "Uploading... "+Math.floor(MetacraneClient.uploadProgress*100)+"%"
    }

    SilicaListView {
        id: listView
        anchors.fill: parent

        PullDownMenu {
            MenuItem {
                text: "Upload Text"
                onClicked: pageStack.push(Qt.resolvedUrl("UploadTextPage.qml"), {
                    crane_name: crane_name
                })
            }
            MenuItem {
                text: "Upload File"
                onClicked: pageStack.push(Qt.resolvedUrl("UploadFilePage.qml"), {
                    crane_name: crane_name
                })
            }
        }

        header: PageHeader {
            title: ""+crane_name+" | Metacrane"
        }
        model: MetacraneClient.entities
        delegate: ListItem {
            id: delegate
            height: Theme.itemSizeSmall + Theme.paddingMedium * 2

            Label {
                id: mainLabel
                x: Theme.fontSizeSmall*2.5 + Theme.paddingLarge
                //width: listView.contentWidth
                width: page.width - Theme.paddingLarge * 2 - Theme.fontSizeSmall*2.5
                text:
                    modelData.components.file_meta ?
                        modelData.components.file_meta.name :
                    modelData.components.text ?
                        modelData.components.text.text :
                    modelData.components.description ?
                        modelData.components.description.text :
                    "Item "+index
                anchors.verticalCenter: parent.verticalCenter
                color: delegate.highlighted ? Theme.highlightColor : Theme.primaryColor
                wrapMode: Text.Wrap
                font.underline: modelData.components.file_meta ? true : false
            }
            Label {
                anchors.bottom: parent.bottom
                anchors.right: parent.right
                anchors.margins: Theme.paddingLarge
                font.pixelSize: Theme.fontSizeSmall
                color: Theme.secondaryColor
                text: modelData.components.file_meta ?
                        prettySize(modelData.components.file_meta.size) : ""
            }
            Label {
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                anchors.margins: Theme.paddingLarge
                font.pixelSize: Theme.fontSizeSmall
                color: Theme.secondaryColor
                text:
                    modelData.components.file_meta ? "File" :
                    modelData.components.text ? "Text" :
                    modelData.components.description ? "?" :
                    "("+index+") ?"
            }
            onClicked: {
                console.log("Clicked " + index)
                if(modelData.components.file_meta){
                    console.log("Is file")
                    var sid = MetacraneClient.currentSafeId()
                    var e = modelData.entity
                    var fname = modelData.components.file_meta.name
                    var url = "https://metacrane.com/f/"+sid+"/"+e+"/"+fname
                    console.log("Opening "+url)
                    MetacraneClient.openUrl(url)
                    return
                }
                if(modelData.components.text){
                    console.log("Is text")
                    pageStack.push("ViewText.qml", {
                        item_text: modelData.components.text.text
                    })
                    return
                }
                console.log("Is nothing")
            }
        }
        VerticalScrollDecorator {}
    }

    Connections {
        target: MetacraneClient
        onLastMessageChanged: {
            console.log("onLastMessageChanged: "+MetacraneClient.lastMessage)
            showMessageTimer.start()
        }
    }
    Timer {
        id: showMessageTimer
        interval: 1000
        onTriggered: {
            pageStack.push("MessageDialog.qml", {
                message: MetacraneClient.lastMessage
            })
        }
    }

    function prettySize(size){
        if(size >= 1024*1024*2)
            return ""+Math.round(size/1024/1024)+"MB"
        else if(size >= 1024*2)
            return ""+Math.round(size/1024)+"KB"
        return ""+size+"B"
    }
}
